==> v26.0.11rc2.tar.gz: nextcloud/apps/updatenotification/l10n/es_EC.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponible. Obten más información de cómo actualizar. ",
    "Channel updated" : "Canal actualizado",
    "Web updater is disabled" : "El actualizador web está desactivado",
    "Update notifications" : "Actualizar notificaciones",
    "The update server could not be reached since %d days to check for new updates." : "El servidor de actualización no ha podido ser alcanzado desde %d días para verificar actualizaciones. ",
    "Please check the Nextcloud and server log files for errors." : "Por favor verifica los archivos de bitacoras de Nextcloud y del servidor por errores. ",
    "Update to %1$s is available." : "La actualización a %1$s está disponible. ",
    "Update to {serverAndVersion} is available." : "Hay una actualización disponible a {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Actualización para {app} a la versión %s está disponible.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Muestra notificaciones de actualización para Nextcloud y proporciona SSO para el actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versión que estas corriendo ya no cuenta con mantenimiento. Por favor asegurate de actualizar a una versión soportada lo antes posible. ",
    "Apps missing compatible version" : "Aplicaciones sin versión compatible",
    "View in store" : "Ver en la tienda",
    "Apps with compatible version" : "Aplicaciones con versión compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Ten en cuenta que el actualizador web no se recomienda para más de 100 usuarios. ¡Utiliza en su lugar el actualizador de línea de comandos!",
    "Open updater" : "Abrir actualizador",
    "Download now" : "Descargar ahora",
    "What's new?" : "¿Qué hay de nuevo?",
    "View changelog" : "Ver registro de cambios",
    "The update check is not yet finished. Please refresh the page." : "La verificación de actualización aún no termina. Por favor actualiza la página.",
    "Your version is up to date." : "Tu verisón está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Un servidor de actualizaciones no-predeterminado está en uso para ser verficiado por actualizaciones:",
    "Update channel" : "Canal de actualización",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Al cambiar el canal de actualización, también se afecta la página de administración de aplicaciones. Por ejemplo, al cambiar al canal beta, se te ofrecerán actualizaciones beta de aplicaciones en la página de administración de aplicaciones.",
    "Current update channel:" : "Canal de actualización actual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Siempre puedes actualizar a una versión más nueva. Pero nunca puedes retroceder a una versión más estable.",
    "Notify members of the following groups about available updates:" : "Notificar a los miembros de los siguientes grupos de las actualizaciones disponibles:",
    "No groups" : "Sin grupos",
    "Only notifications for app updates are available." : "Solo están disponibles notificaciones para actualizaciones de aplicaciones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal de actualización seleccionado hace que las notificaciones dedicadas al servidor sean obsoletas. ",
    "The selected update channel does not support updates of the server." : "El canal de actualización seleccionado no soporta actualizaciones del servidor. ",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versión más reciente está disponible: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Ten en cuenta que después de un nuevo lanzamiento, la actualización solo se mostrará después del primer lanzamiento menor o posterior. Lanzamos nuevas versiones de forma escalonada a nuestros usuarios y a veces omitimos una versión cuando se encuentran problemas. Obtén más información sobre las actualizaciones y los canales de lanzamiento en {link}",
    "Checking apps for compatible versions" : "Comprobando aplicaciones en busca de versiones compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor asegurate que en tu config.php no se establezca <samp>appstoreenabled</samp> como falso.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se pudo conectar con la Tienda de aplicaciones o no se han devuelto actualizaciones en absoluto. Busca actualizaciones manualmente o asegúrate de que tu servidor tenga acceso a Internet y pueda conectarse a la Tienda de aplicaciones.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> las aplicaciones tienen una versión compatible disponible para esta versión de Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Siempre proporciona el último nivel de parche, pero no se actualizará inmediatamente a la siguiente versión principal. Esa actualización se realizará una vez que Nextcloud GmbH haya realizado una mayor fortificación y pruebas para implementaciones a gran escala y críticas para la misión. Este canal solo está disponible para clientes y proporciona el paquete Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versión estable más reciente. Es adecuada para uso regular y siempre se actualizará a la última versión principal.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versión previa al lanzamiento solo para probar nuevas funciones, no apta para entornos de producción.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicación no tiene una versión compatible disponible para esta versión de Nextcloud.","<strong>%n</strong> aplicaciones no tienen una versión compatible disponible para esta versión de Nextcloud.","<strong>%n</strong> aplicaciones no tienen una versión compatible disponible para esta versión de Nextcloud."],
    "Please use the command line updater to update." : "Utiliza el actualizador de línea de comandos para actualizar.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Puedes cambiar el canal de actualización a continuación, lo cual también afecta la página de administración de aplicaciones. Por ejemplo, al cambiar al canal beta, se te ofrecerán actualizaciones beta de aplicaciones en la página de administración de aplicaciones.",
    "Update channel:" : "Actualizar el canal:",
    "Checked on {lastCheckedDate}" : "Verificado el {lastCheckedDate}"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> v28.0.1rc1.tar.gz: nextcloud/apps/updatenotification/l10n/es_EC.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} está disponible. Obten más información de cómo actualizar. ",
    "Channel updated" : "Canal actualizado",
    "Web updater is disabled" : "El actualizador web está desactivado",
    "Update notifications" : "Actualizar notificaciones",
    "The update server could not be reached since %d days to check for new updates." : "El servidor de actualización no ha podido ser alcanzado desde %d días para verificar actualizaciones. ",
    "Please check the Nextcloud and server log files for errors." : "Por favor verifica los archivos de bitacoras de Nextcloud y del servidor por errores. ",
    "Update to %1$s is available." : "La actualización a %1$s está disponible. ",
    "Update to {serverAndVersion} is available." : "Hay una actualización disponible a {serverAndVersion}.",
    "Update for {app} to version %s is available." : "Actualización para {app} a la versión %s está disponible.",
    "Update notification" : "Notificación de actualización",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Muestra notificaciones de actualización para Nextcloud y proporciona SSO para el actualizador.",
    "Update" : "Actualizar",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versión que estas corriendo ya no cuenta con mantenimiento. Por favor asegurate de actualizar a una versión soportada lo antes posible. ",
    "Apps missing compatible version" : "Aplicaciones sin versión compatible",
    "View in store" : "Ver en la tienda",
    "Apps with compatible version" : "Aplicaciones con versión compatible",
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Ten en cuenta que el actualizador web no se recomienda para más de 100 usuarios. ¡Utiliza en su lugar el actualizador de línea de comandos!",
    "Open updater" : "Abrir actualizador",
    "Download now" : "Descargar ahora",
    "What's new?" : "¿Qué hay de nuevo?",
    "View changelog" : "Ver registro de cambios",
    "The update check is not yet finished. Please refresh the page." : "La verificación de actualización aún no termina. Por favor actualiza la página.",
    "Your version is up to date." : "Tu verisón está actualizada.",
    "A non-default update server is in use to be checked for updates:" : "Un servidor de actualizaciones no-predeterminado está en uso para ser verficiado por actualizaciones:",
    "Update channel" : "Canal de actualización",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Al cambiar el canal de actualización, también se afecta la página de administración de aplicaciones. Por ejemplo, al cambiar al canal beta, se te ofrecerán actualizaciones beta de aplicaciones en la página de administración de aplicaciones.",
    "Current update channel:" : "Canal de actualización actual:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Siempre puedes actualizar a una versión más nueva. Pero nunca puedes retroceder a una versión más estable.",
    "Notify members of the following groups about available updates:" : "Notificar a los miembros de los siguientes grupos de las actualizaciones disponibles:",
    "No groups" : "Sin grupos",
    "Only notifications for app updates are available." : "Solo están disponibles notificaciones para actualizaciones de aplicaciones.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "El canal de actualización seleccionado hace que las notificaciones dedicadas al servidor sean obsoletas. ",
    "The selected update channel does not support updates of the server." : "El canal de actualización seleccionado no soporta actualizaciones del servidor. ",
    "A new version is available: <strong>{newVersionString}</strong>" : "Una versión más reciente está disponible: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Ten en cuenta que después de un nuevo lanzamiento, la actualización solo se mostrará después del primer lanzamiento menor o posterior. Lanzamos nuevas versiones de forma escalonada a nuestros usuarios y a veces omitimos una versión cuando se encuentran problemas. Obtén más información sobre las actualizaciones y los canales de lanzamiento en {link}",
    "Checked on {lastCheckedDate}" : "Verificado el {lastCheckedDate}",
    "Checking apps for compatible versions" : "Comprobando aplicaciones en busca de versiones compatibles",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Por favor asegurate que en tu config.php no se establezca <samp>appstoreenabled</samp> como falso.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "No se pudo conectar con la Tienda de aplicaciones o no se han devuelto actualizaciones en absoluto. Busca actualizaciones manualmente o asegúrate de que tu servidor tenga acceso a Internet y pueda conectarse a la Tienda de aplicaciones.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todas</strong> las aplicaciones tienen una versión compatible disponible para esta versión de Nextcloud.",
    "Enterprise" : "Enterprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Siempre proporciona el último nivel de parche, pero no se actualizará inmediatamente a la siguiente versión principal. Esa actualización se realizará una vez que Nextcloud GmbH haya realizado una mayor fortificación y pruebas para implementaciones a gran escala y críticas para la misión. Este canal solo está disponible para clientes y proporciona el paquete Nextcloud Enterprise.",
    "Stable" : "Estable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La versión estable más reciente. Es adecuada para uso regular y siempre se actualizará a la última versión principal.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Una versión previa al lanzamiento solo para probar nuevas funciones, no apta para entornos de producción.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicación no tiene una versión compatible disponible para esta versión de Nextcloud.","<strong>%n</strong> aplicaciones no tienen una versión compatible disponible para esta versión de Nextcloud.","<strong>%n</strong> aplicaciones no tienen una versión compatible disponible para esta versión de Nextcloud."],
    "Please use the command line updater to update." : "Utiliza el actualizador de línea de comandos para actualizar.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Puedes cambiar el canal de actualización a continuación, lo cual también afecta la página de administración de aplicaciones. Por ejemplo, al cambiar al canal beta, se te ofrecerán actualizaciones beta de aplicaciones en la página de administración de aplicaciones.",
    "Update channel:" : "Actualizar el canal:"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
